/*global Configuration, getLocalVar, moment*/
var Cus02800_ComparativoCustoPerCapita = function(General, GeneralServices, templateManager, ZhUtil, CUSUtilities) {
  var self = this;
  this.defaultValues = function(widget) {
    let firstReport = widget.getField('CD_REPORT_NAME').dataSource.getFirstRow();
    let currentDate = moment().format('DD/MM/YYYY');
    let currentMonthYear = moment().format('MM/YYYY');
    
    widget.currentRow.CD_REPORT_NAME = firstReport.value;
    
    widget.getField('DTCUSTOBASE').setValue(currentDate);
    widget.getField('DTCARDAPIO').setValue(currentMonthYear);
    widget.getField('NMTIPOCUSTO').reload().then(callback => {
      let typeOfCost = callback.dataset.type_cost_lang;
      
      if(typeOfCost && typeOfCost.length){
        let currentCost = typeOfCost[0];
        widget.currentRow.NMTIPOCUSTO = currentCost.CDTIPOCUSTO + ' | ' + currentCost.NMTIPOCUSTO;
        widget.currentRow.CDTIPOCUSTO = currentCost.CDTIPOCUSTO;
      }
    });
		
  }; 
  
  this.filtrarUnidades = function(widget) {
    let cdgrupfili = 'T';

		widget.getField('NMFILIAL').clearValue();
		widget.getField('CDSERVFILI').applyDefaultValue();
		widget.getField('CDSERVFILI').dataSourceFilter = [];

		if (widget.getField('NMGRUPFILI').value()) {
			cdgrupfili = widget.currentRow.CDGRUPFILI;
		} else {
			widget.currentRow.CDGRUPFILI = 'T';
		}
		
    widget.getField('NMFILIAL').dataSourceFilter = [
      {
        "name": "CDGRUPFILI",
        "operator": "=",
        "value": cdgrupfili
      },
      {
        "name": "CDOPERADOR",
        "operator": "=",
        "value": getLocalVar('CDOPERADOR')
      }
    ];
    
    widget.getField('NMFILIAL').reload();
  };
  
  this.unityOnChange = function(args) {
		var field = args.owner.field;
		var widget = field.widget;

		widget.getField('CDSERVFILI').setValue([]);
		if (!field.value()) {
			widget.currentRow.CDFILIAL = '';
		}    
  };
  
  this.onChangeAllFilial = function(args) {
    let cdServFili = args.owner.field.widget.getField('CDSERVFILI');
    let field = args.owner.field;
    
    if(field.value() == 'N') {
      cdServFili.setValue([]);
    }
  };
  
  this.changeServiceFilter = function(widget) {
  	let filiais = '';
  	let currentRow = widget.currentRow;
  	let cdgrupfili = widget.currentRow.CDGRUPFILI;
  
  	if (currentRow.ALLFILIAL == 'N') {
  		if (currentRow.NMFILIAL && currentRow.NMFILIAL.length > 0) {
  		  filiais = currentRow.NMFILIAL.join('_');
  		} else {
  			filiais = '';
  		}
  	} else {
  		filiais = 'T';
  	}
  
  	if (!cdgrupfili) {
  		cdgrupfili = "T";
  	}
  
  	widget.getField('CDSERVFILI').dataSourceFilter = [
  		{
  			name: "CDGRUPFILI",
  			operator: "=",
  			value: cdgrupfili
  	  },
  		{
  			name: "CDFILIAL",
  			operator: "=",
  			value: filiais
  	    },
  		{
  			name: "NRORG",
  			operator: "=",
  			value: getLocalVar('NRORG')
  	  },
  		{
  			name: "CDOPERADOR",
  			operator: "=",
  			value: getLocalVar('CDOPERADOR')
  	  }
    ];
  
  	widget.getField('CDSERVFILI').reload();    
  };
  
  this.getAllServices = function(NMFILIAL, CDGRUPSERV, CDGRUPFILI) {
    return General.callRestEngine("cus#/servicos_por_agrupfili_multi_filiais", "FilterData", [
      {
        "name": "CDOPERADOR",
        "operator": "=",
        "value": getLocalVar('CDOPERADOR')
      },
      {
        "name": "CDGRUPFILI",
        "operator": "=",
        "value": CDGRUPFILI
      },
      {
        "name": "CDFILIAL",
        "operator": "=",
        "value": NMFILIAL
      },
      {
        "name": "NRORG",
        "operator": "=",
        "value": getLocalVar('NRORG')
      }
    ]);
  };
  
  this.validateFields = function(widget, row, currentRow) {
		var reportName = widget.currentRow.CD_REPORT_NAME;
		
		if(widget.isValid()) {
		  currentRow.LISTASERVFILI = undefined;
		  
      if (currentRow.ALLSERVFILI == 'N' && Array.isArray(currentRow.CDSERVFILI) && currentRow.CDSERVFILI.length > 0) {
        currentRow.LISTASERVFILI = currentRow.CDSERVFILI.map(code => code.CDFILIAL + code.CDSERVFILI);
        row.LISTASERVFILI = currentRow.LISTASERVFILI;
      } else {
        if(!row.CDSERVFILI && row.ALLSERVFILI == 'S') {
          row.CDSERVFILI = 'T';
        } else {
          row.CDSERVFILI = row.CDSERVFILI;
        }
        row.CDFILIAL = row.ALLFILIAL == 'S' ? 'T' : row.NMFILIAL.join('_');
        row.CDGRUPFILI = !row.CDGRUPFILI ? 'T' : row.CDGRUPFILI;
        
        self.getAllServices(row.CDFILIAL, 'T', row.CDGRUPFILI).then(callback => {
          row.LISTASERVFILI = callback.dataset.servicos_por_agrupfili_multi_filiais.map(code => code.CDFILIAL + code.CDSERVFILI);
        });
      }
      
		  row.dtMesCardIni =  moment(row.DTCARDAPIO, 'MM/YYYY').startOf('month').format('DD/MM/YYYY');
		  row.dtMesCardFim = moment(row.DTCARDAPIO, 'MM/YYYY').endOf('month').format('DD/MM/YYYY');

		  
  		var reportFormats = [
  	    {
	        name: "pdf",
	        value: "PDF"
  	    },
		    {
	        name: "xlsx",
	        value: "XLSX"
		    }
  		];
  	
  		General.openReportPopup(widget, this.abreRelatorio, [reportName, row, currentRow], reportFormats);
		}
		    
  };
  
	this.abreRelatorio = function(reportName, row, currentRow) {
		General.openReport('cus_relatorio#/Cus02800_ComparativoCustoPerCapita', reportName, row);
	}.bind(this);  
  
};

Configuration(function(ContextRegister) {
	ContextRegister.register('Cus02800_ComparativoCustoPerCapita', Cus02800_ComparativoCustoPerCapita);
});